<?php
namespace BancoTalentos\Controllers;

use BancoTalentos\Services\PerfilService;
use Zeedhi\Framework\DTO\{ Request, Response };
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\{ Error, Message };
use Ems\Util\ExpectedException;

class PerfilController {
    /** @param PerfilService */
    protected $perfilService;

    public function __construct(
        PerfilService $perfilService
    ) {
        $this->perfilService = $perfilService;
    }

    public function generateResume(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $link = $this->perfilService->generateResume();

            $dataSet = [
                'link' => $link,
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getQtVagasRelacionadas(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $qtVagasRel = $this->perfilService->getQtVagasRelacionadas();

            $response->addDataSet(new DataSet('data', $qtVagasRel));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getUltimaAtualizacao(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $ultAtu = $this->perfilService->getUltimaAtualizacao();

            if ($ultAtu === false) {
                $ultAtu = [];
            }

            $response->addDataSet(new DataSet('data', $ultAtu));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

}